@@ -25,12 +25,12 @@ void GIBBS_sumpred_txt_ar(int *aggtype, double *flag, int *its, int *burnin,
 //     unsigned iseed = 44;
 //     srand(iseed); 
      
-     int its1, col, i, j, n1, r1, T1, p1, N1, nr, rep1, nsite1, brin, trans1;
+     int its1, col, i, j, n1, r1, rT1, p1, N1, nr, rep1, nsite1, brin, trans1;
      its1 = *its;
      col = *constant;
      n1 = *n;
      r1 = *r;
-     T1 = *T;
+     rT1 =*rT;
      p1 = *p;
      N1 = *N;
      nr = n1 * r1;
@@ -55,9 +55,9 @@ void GIBBS_sumpred_txt_ar(int *aggtype, double *flag, int *its, int *burnin,
      }      
          
      double *pr_mn, *pr_var;
-     pr_mn = (double *) malloc((size_t)((nsite1*r1*T1)*sizeof(double))); 
-     pr_var = (double *) malloc((size_t)((nsite1*r1*T1)*sizeof(double))); 
-     for(j=0; j<nsite1*r1*T1; j++){
+     pr_mn = (double *) malloc((size_t)((nsite1*rT1)*sizeof(double))); 
+     pr_var = (double *) malloc((size_t)((nsite1*rT1)*sizeof(double))); 
+     for(j=0; j<nsite1*rT1; j++){
           pr_mn[j] = 0.0;
           pr_var[j] = 0.0;
      }         
@@ -86,7 +86,7 @@ void GIBBS_sumpred_txt_ar(int *aggtype, double *flag, int *its, int *burnin,
      acc = (double *) malloc((size_t)((col)*sizeof(double)));
 
      double *zp, *anf;
-     zp = (double *) malloc((size_t)((nsite1*r1*T1)*sizeof(double)));      
+     zp = (double *) malloc((size_t)((nsite1*rT1)*sizeof(double)));      
      anf = (double *) malloc((size_t)((nsite1*r1)*sizeof(double)));      
  
      double *nu, *nup;
@@ -154,7 +154,7 @@ void GIBBS_sumpred_txt_ar(int *aggtype, double *flag, int *its, int *burnin,
      sig_e1, sig_eta1, sig_01, mu_l1, rho1, beta1, X, z, o1, 
      phip, acc, nup, sig_ep, sig_etap, rhop, betap, mu_lp, sig_0p, op, w);
 
-     z_pr_ar(cov, nsite, n, r, rT, T, p, N, predN, d, d12, phip, nup, sig_ep, 
+     z_pr_ar(cov, nsite, n, r, rT, T, p, N, d, d12, phip, nup, sig_ep, 
      sig_etap, sig_0p, rhop, betap, mu_lp, X, predX, op, constant, zp);
      
      accept1 += acc[0];
@@ -191,7 +191,7 @@ void GIBBS_sumpred_txt_ar(int *aggtype, double *flag, int *its, int *burnin,
      }
 
 // prediction samples
-     for(j=0; j<(nsite1*r1*T1); j++){
+     for(j=0; j<(nsite1*rT1); j++){
          if(trans1 == 0){
          if(i >= brin){  
            zp[j] = zp[j];
@@ -227,7 +227,8 @@ void GIBBS_sumpred_txt_ar(int *aggtype, double *flag, int *its, int *burnin,
      }
 
       if(i >= brin){
-        annual_aggregate(aggtype, nsite, r, T, zp, anf);
+        annual_aggregate_uneqT(aggtype, nsite, r, T, rT, zp, anf);
+//        annual_aggregate(aggtype, nsite, r, T, zp, anf);
   	     for(j=0; j<(nsite1*r1); j++){
            fprintf(textan, "%f ", anf[j]);
          }
@@ -315,7 +316,7 @@ void GIBBS_sumpred_txt_ar(int *aggtype, double *flag, int *its, int *burnin,
 
 
 // predicted mean and sd
-     for(j=0; j < nsite1*r1*T1; j++){
+     for(j=0; j < nsite1*rT1; j++){
           pr_mn[j] = pr_mn[j]/iit;
           pr_var[j] = pr_var[j]/iit;
           pr_var[j] = pr_var[j] - pr_mn[j]*pr_mn[j];
